@@ -1,16 +1,18 @@
 /*
- * Copyright (c) 2016, 2023, Oracle and/or its affiliates.
+ * Copyright (c) 2016, 2024, Oracle and/or its affiliates.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License, version 2.0,
  * as published by the Free Software Foundation.
  *
- * This program is also distributed with certain software (including
- * but not limited to OpenSSL) that is licensed under separate terms, as
- * designated in a particular file or component or in included license
+ * This program is designed to work with certain software (including
+ * but not limited to OpenSSL) that is licensed under separate terms,
+ * as designated in a particular file or component or in included license
  * documentation.  The authors of MySQL hereby grant you an additional
  * permission to link the program and your derivative works with the
- * separately licensed software that they have included with MySQL.
+ * separately licensed software that they have either included with
+ * the program or referenced in the documentation.
+ *
  * This program is distributed in the hope that it will be useful,  but
  * WITHOUT ANY WARRANTY; without even the implied warranty of
  * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See
@@ -981,6 +983,8 @@ bool MySQLBaseLexer::isOperator(size_t type) {
     case MySQLLexer::COLON_SYMBOL:
     case MySQLLexer::OPEN_PAR_SYMBOL:
     case MySQLLexer::CLOSE_PAR_SYMBOL:
+    case MySQLLexer::OPEN_CURLY_SYMBOL:
+    case MySQLLexer::CLOSE_CURLY_SYMBOL:
     case MySQLLexer::AT_SIGN_SYMBOL:
     case MySQLLexer::PARAM_MARKER:
       return true;
