@@ -86,14 +86,8 @@ function call_and_validate(callback, expect_tag) {
     EXPECT_NO_THROWS(callback);
 
     if (expect_tag.endsWith('WARNING')) {
-        if (__version_num < 80000) {
-            EXPECT_NEXT_OUTPUT('WARNING: Support for AdminAPI operations in MySQL version 5.7 is deprecated and will be removed in a future release of MySQL Shell');
-        }
         EXPECT_NEXT_OUTPUT('WARNING: ' + messages[expect_tag]);
     } else if (expect_tag.endsWith('NOTE')) {
-        if (__version_num < 80000) {
-            EXPECT_NEXT_OUTPUT('WARNING: Support for AdminAPI operations in MySQL version 5.7 is deprecated and will be removed in a future release of MySQL Shell');
-        }
         EXPECT_NEXT_OUTPUT('NOTE: ' + messages[expect_tag]);
     }
 }
@@ -228,7 +222,6 @@ for (index in tests) {
 //@<> getCluster test: compatible metadata
 testutil.destroySandbox(__mysql_sandbox_port1);
 testutil.deploySandbox(__mysql_sandbox_port1, "root", {report_host: hostname});
-// Sandbox to be used in Cluster.checkInstanceState
 testutil.deploySandbox(__mysql_sandbox_port2, "root", {report_host: hostname});
 shell.connect(__sandbox_uri1);
 
@@ -305,11 +298,6 @@ for (index in tests) {
             print_debug("Cluster.describe()");
             testutil.wipeAllOutput();
             println(cluster.describe())
-        },
-        function () {
-            print_debug("Cluster.checkInstanceState()");
-            testutil.wipeAllOutput();
-            println(cluster.checkInstanceState(__sandbox_uri2));
         }
     ]
 
